@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Sequence
 
 from .literals import (
     InstanceAccessControlAttributeConfigurationStatusType,
@@ -113,7 +113,7 @@ AccessControlAttributeTypeDef = TypedDict(
 AccessControlAttributeValueTypeDef = TypedDict(
     "AccessControlAttributeValueTypeDef",
     {
-        "Source": List[str],
+        "Source": Sequence[str],
     },
 )
 
@@ -213,7 +213,7 @@ _OptionalCreatePermissionSetRequestRequestTypeDef = TypedDict(
         "Description": str,
         "SessionDuration": str,
         "RelayState": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -386,7 +386,7 @@ GetInlinePolicyForPermissionSetResponseTypeDef = TypedDict(
 InstanceAccessControlAttributeConfigurationTypeDef = TypedDict(
     "InstanceAccessControlAttributeConfigurationTypeDef",
     {
-        "AccessControlAttributes": List["AccessControlAttributeTypeDef"],
+        "AccessControlAttributes": Sequence["AccessControlAttributeTypeDef"],
     },
 )
 
@@ -826,7 +826,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     {
         "InstanceArn": str,
         "ResourceArn": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -844,7 +844,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     {
         "InstanceArn": str,
         "ResourceArn": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
